/* Schedwi
   Copyright (C) 2007-2014 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* @file startjob.h
 * Start a job.
 */

#ifndef _STARTJOB_H
#define _STARTJOB_H

#include <schedwi.h>
#include <lwc_linkedlist.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int startjob OF((lwc_LL *hierarchy_list,
			const char *path,
			int workload_date,
			unsigned long long int job_id,
			char **out_message));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* startjob.h */

/*-----------------============== End Of File ==============-----------------*/
